![PyPI](https://img.shields.io/pypi/v/FooFinder)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/FooFinder)
[![Build Status](https://travis-ci.org/MadisonAster/FooFinder.svg?branch=master)](https://travis-ci.org/MadisonAster/FooFinder)


A package designed to help you find foo.

## Installation:
```
pip install FooFinder
```

## Usage:
```
import FooFinder
from FooFinder import MySuperAwesomeModule
```

FooFinder will walk up to each parent directory from your current module and look for a module to import with the name you give it.
